@@ -4,4 +4,4 @@ from .command import CommandHandler
 
 
 class StartHandler(CommandHandler, ABC):
-    on_command: str = "start"
+    on_command = "start"
